@@ -10,7 +10,7 @@ c.ServerApp.port_retries = 0
 c.ServerApp.open_browser = False
 c.LabApp.dev_mode = True
 
-c.ServerApp.root_dir = mkdtemp(prefix='galata-test-')
+c.ServerApp.root_dir = mkdtemp(prefix="galata-test-")
 c.ServerApp.token = ""
 c.ServerApp.password = ""
 c.ServerApp.disable_check_xsrf = True
