@@ -1,8 +1,7 @@
 // Copyright (c) Jupyter Development Team.
 // Distributed under the terms of the Modified BSD License.
 
-import { IJupyterLabPageFixture, test } from '@jupyterlab/galata';
-import { expect } from '@playwright/test';
+import { expect, IJupyterLabPageFixture, test } from '@jupyterlab/galata';
 
 const fileName = 'notebook.ipynb';
 
@@ -13,7 +12,6 @@ async function populateNotebook(page: IJupyterLabPageFixture) {
     '## This is **bold** and *italic* [link to jupyter.org!](http://jupyter.org)'
   );
   await page.notebook.addCell('code', '2 ** 3');
-  // await page.notebook.runCell(2, true);
 }
 
 test.describe('Notebook Toolbar', () => {
@@ -100,3 +98,42 @@ test.describe('Notebook Toolbar', () => {
     expect(await nbPanel.screenshot()).toMatchSnapshot(imageName);
   });
 });
+
+test('Toolbar items act on owner widget', async ({ page }) => {
+  // Given two side-by-side notebooks and the second being active
+  const file1 = 'notebook1.ipynb';
+  await page.notebook.createNew(file1);
+  const panel1 = await page.activity.getPanel(file1);
+  const tab1 = await page.activity.getTab(file1);
+
+  // FIXME Calling a second time `page.notebook.createNew` is not robust
+  await page.menu.clickMenuItem('File>New>Notebook');
+  try {
+    await page.waitForSelector('.jp-Dialog', { timeout: 5000 });
+    await page.click('.jp-Dialog .jp-mod-accept');
+  } catch (reason) {
+    // no-op
+  }
+
+  const tab2 = await page.activity.getTab();
+
+  const tab2BBox = await tab2.boundingBox();
+  await page.mouse.move(
+    tab2BBox.x + 0.5 * tab2BBox.width,
+    tab2BBox.y + 0.5 * tab2BBox.height
+  );
+  await page.mouse.down();
+  await page.mouse.move(900, tab2BBox.y + tab2BBox.height + 200);
+  await page.mouse.up();
+
+  const classlist = await tab1.getAttribute('class');
+  expect(classlist.split(' ')).not.toContain('jp-mod-current');
+
+  // When clicking on toolbar item of the first file
+  await (await panel1.$('button[title="Insert a cell below (B)"]')).click();
+
+  // Then the first file is activated and the action is performed
+  const classlistEnd = await tab1.getAttribute('class');
+  expect(classlistEnd.split(' ')).toContain('jp-mod-current');
+  expect(await page.notebook.getCellCount()).toEqual(2);
+});
