@@ -126,12 +126,16 @@ test.describe('Workspace', () => {
     tmpPath
   }) => {
     await Promise.all([
-      // Wait for the workspace to be saved
+      // Wait for the workspace to be saved.
+      // The document opened from URL should not be saved in workspace,
+      // to not change the workspace for 'multiple-document' mode.
       page.waitForResponse(
         response =>
           response.request().method() === 'PUT' &&
           /api\/workspaces/.test(response.request().url()) &&
-          response.request().postDataJSON().data[`editor:${tmpPath}/${mdFile}`]
+          response.request().postDataJSON().data['layout-restorer:data'][
+            'main'
+          ] === null
       ),
       page.goto(`${baseURL}/doc/tree/${tmpPath}/${mdFile}`)
     ]);
@@ -225,3 +229,145 @@ test.describe('Workspace', () => {
     await expect(page.locator(`[role="main"] >> text=${nbFile}`)).toBeVisible();
   });
 });
+
+test.describe('Workspace in doc mode', () => {
+  test.beforeAll(async ({ baseURL, tmpPath }) => {
+    const contents = galata.newContentsHelper(baseURL);
+    await contents.uploadFile(
+      path.resolve(__dirname, `./notebooks/${nbFile}`),
+      `${tmpPath}/${nbFile}`
+    );
+    await contents.uploadFile(
+      path.resolve(__dirname, `./notebooks/${mdFile}`),
+      `${tmpPath}/${mdFile}`
+    );
+  });
+
+  test.afterAll(async ({ baseURL, tmpPath }) => {
+    const contents = galata.newContentsHelper(baseURL);
+    await contents.deleteDirectory(tmpPath);
+  });
+
+  // Use non-default state to have the running session panel displayed
+  test.use({
+    mockState: {
+      'layout-restorer:data': {
+        main: {
+          dock: {
+            type: 'tab-area',
+            currentIndex: 0,
+            widgets: ['notebook:workspace-test/simple_notebook.ipynb']
+          }
+        },
+        down: {
+          size: 0,
+          widgets: []
+        },
+        left: {
+          collapsed: false,
+          visible: true,
+          current: 'filebrowser',
+          widgets: [
+            'filebrowser',
+            'running-sessions',
+            '@jupyterlab/toc:plugin',
+            'extensionmanager.main-view'
+          ]
+        },
+        right: {
+          collapsed: true,
+          visible: true,
+          widgets: []
+        },
+        relativeSizes: [0.4, 0.6, 0],
+        top: {
+          simpleVisibility: true
+        }
+      },
+      'file-browser-filebrowser:cwd': {
+        path: 'workspace-test'
+      },
+      'notebook:workspace-test/simple_notebook.ipynb': {
+        data: {
+          path: 'workspace-test/simple_notebook.ipynb',
+          factory: 'Notebook'
+        }
+      }
+    } as any
+  });
+
+  test('should restore workspace when switching back to lab mode', async ({
+    baseURL,
+    page,
+    tmpPath
+  }) => {
+    // Open the browser in doc mode.
+    // This should not change the saved workspace's main area information,
+    // the document opened from URL should not be saved in workspace.
+    await Promise.all([
+      // Wait for the workspace to be saved.
+      page.waitForRequest(request => {
+        if (
+          request.method() !== 'PUT' ||
+          !/api\/workspaces/.test(request.url())
+        ) {
+          return false;
+        }
+        let restorerData: any = {};
+        let mainRestorerWidgets = [];
+        if (request.postDataJSON() && request.postDataJSON().data) {
+          restorerData =
+            request.postDataJSON().data['layout-restorer:data'] ?? {};
+          mainRestorerWidgets = restorerData.main?.dock?.widgets;
+        }
+        return (
+          mainRestorerWidgets.length === 1 &&
+          mainRestorerWidgets[0] ===
+            'notebook:workspace-test/simple_notebook.ipynb'
+        );
+      }),
+      page.goto(`${baseURL}/doc/tree/${tmpPath}/${mdFile}`)
+    ]);
+
+    // Ensure that there is only the document opened, no matter the workspace content.
+    await expect(
+      page.locator('#jp-main-dock-panel .jp-MainAreaWidget .jp-FileEditor')
+    ).toHaveCount(1);
+
+    await expect(
+      page.locator('#jp-main-dock-panel .jp-MainAreaWidget')
+    ).toHaveCount(1);
+
+    // Switch to lab mode, which should restore the loaded workspace.
+    await Promise.all([
+      // Wait for the workspace to be saved.
+      // Expect the saved main area to remain unchanged.
+      page.waitForRequest(request => {
+        let restorerData = {};
+        let mainRestorerWidgets = [];
+        if (request.postDataJSON() && request.postDataJSON().data) {
+          restorerData = request.postDataJSON().data['layout-restorer:data'];
+          mainRestorerWidgets = restorerData['main']['dock']['widgets'];
+        }
+        return (
+          request.method() === 'PUT' &&
+          /api\/workspaces/.test(request.url()) &&
+          mainRestorerWidgets.length === 1 &&
+          mainRestorerWidgets[0] ===
+            'notebook:workspace-test/simple_notebook.ipynb'
+        );
+      }),
+      page.url() === `${baseURL}/lab`,
+      page.click('button.jp-switch[role="switch"]')
+    ]);
+
+    // Ensure that the document opened by URL is closed, and that the one from workspace file is restored.
+    await expect(
+      page.locator('#jp-main-dock-panel .jp-MainAreaWidget .jp-Notebook')
+    ).toHaveCount(1);
+
+    await expect(
+      page.locator('#jp-main-dock-panel .jp-MainAreaWidget')
+    ).toHaveCount(1);
+  });
+});
